@@ -30,7 +30,7 @@ https://github.com/derek-schaefer/django-json-field/
 """
 
 from django.forms import fields, util
-import yajl as json
+from django.utils import simplejson as json
 
 import datetime
 
@@ -55,14 +55,14 @@ class JSONFormField(fields.Field):
         value = value.replace('\r', '').replace('\n', '')
 
         json_globals = { # safety first!
-            '__builtins__': None,
+                         '__builtins__': None,
         }
         if not self.simple: # optional restriction
             json_globals.update({'datetime':datetime})
         json_locals = { # value compatibility
-            'null': None,
-            'true': True,
-            'false': False,
+                        'null': None,
+                        'true': True,
+                        'false': False,
         }
         try:
             value = json.dumps(eval(value, json_globals, json_locals), **self.encoder_kwargs)
@@ -70,7 +70,7 @@ class JSONFormField(fields.Field):
             raise util.ValidationError('%s (Caught "%s")' % (self.help_text, e))
 
         try:
-            json.loads(value)
+            json.loads(value, **self.decoder_kwargs)
         except ValueError, e:
             raise util.ValidationError('%s (Caught "%s")' % (self.help_text, e))
 
