@@ -14,9 +14,14 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+import re
 from django.core.exceptions import ValidationError
 from eggplant.utils.string import str2bool
 
+def is_hex(value):
+    if re.compile(r'^[a-fA-F0-9]*$').match(value) is None:
+        raise ValidationError('%s is not a valid hex string'%value)
+
 def is_integer(raw_value):
     try:
         return int(raw_value)
